======================
Mara the Chat Server
======================

Mara is a framework for building telnet-based services such as IRC-like
chatrooms, talkers or muds.

Version 0.6.1

.. seealso::

    Read this online at http://radiac.net/projects/mara/


Contents
========

.. toctree::
    :maxdepth: 2

    introduction
    installation
    upgrading
    contributing
    api/index
